@@ -21,7 +21,7 @@ from ...ext import BaseClient
 
 
 class OnDisconnect(BaseClient):
-    def on_disconnect(self):
+    def on_disconnect(self=None):
         """Use this decorator to automatically register a function for handling
         disconnections. This does the same thing as :meth:`add_handler` using the
         :class:`DisconnectHandler`.
