@@ -44,6 +44,9 @@ class User(Object):
         first_name (``str``):
             User's or bot's first name.
 
+        status (:obj:`UserStatus <pyrogram.UserStatus>`, *optional*):
+            User's Last Seen status. Empty for bots.
+
         last_name (``str``, *optional*):
             User's or bot's last name.
 
@@ -58,6 +61,9 @@ class User(Object):
 
         photo (:obj:`ChatPhoto <pyrogram.ChatPhoto>`, *optional*):
             User's or bot's current profile photo. Suitable for downloads only.
+
+        restriction_reason (``str``, *optional*):
+            The reason why this bot might be unavailable to some users.
     """
 
     ID = 0xb0700001
@@ -71,11 +77,13 @@ class User(Object):
             is_deleted: bool,
             is_bot: bool,
             first_name: str,
+            status=None,
             last_name: str = None,
             username: str = None,
             language_code: str = None,
             phone_number: str = None,
-            photo=None
+            photo=None,
+            restriction_reason: str = None
     ):
         self.id = id
         self.is_self = is_self
@@ -84,8 +92,10 @@ class User(Object):
         self.is_deleted = is_deleted
         self.is_bot = is_bot
         self.first_name = first_name
+        self.status = status
         self.last_name = last_name
         self.username = username
         self.language_code = language_code
         self.phone_number = phone_number
         self.photo = photo
+        self.restriction_reason = restriction_reason
